---
layout: template
title: Concepts
permalink: /documentation/concepts/
link_group: documentation
---
# Concepts

## Devices

### Services and protocols

### Identifiers

### Credentials

## Scanning

## Pairing

## Connecting

## Metadata and push updates
